@@ -1,7 +1,3 @@
-# -*- coding: utf-8 -*-
-# Copyright: 2014 Valentin Pratz <vp.pratz@yahoo.de>
-# License: BSD 2-clause, see LICENSE for details.
-
 import sys
 
 __all__ = ['urljoin', 'urlparse']
@@ -12,9 +8,13 @@ if PY2:
     from urlparse import urlparse, urljoin
 
     range_type = xrange  # noqa: F821
+    bytes_type = str
     iteritems = lambda d: d.iteritems()  # noqa: E731
+    from collections import MutableMapping  # noqa: F401
 else:
     from urllib.parse import urlparse, urljoin
 
     range_type = range
+    bytes_type = bytes
     iteritems = lambda d: iter(d.items())  # noqa: E731
+    from collections.abc import MutableMapping  # noqa: F401
